RxDI class

Global dependency injection container.

Supports:

  • Singleton registration
  • Lazy registration
  • Named instances
  • Automatic disposal

Constructors

RxDI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

delete<T>({String? name}) → void
Removes a dependency from the container.
find<T>({String? name}) → T
Finds a registered dependency.
findOrNull<T>({String? name}) → T?
Finds a registered dependency.
lazyPut<T>(T builder(), {String? name}) → void
Registers a lazy factory.
put<T>(T dependency, {String? name}) → T
Registers a singleton instance.