v property
T
get
v
Returns the current computed value.
Useful when a plain value is required, such as widget properties that do not automatically subscribe to reactive updates.
Implementation
T get v => value;